package internal

import (
	"context"
	"flag"
	"runtime"
	"time"

	"github.com/open-io/oio-exporter/common"
	"github.com/open-io/oio-exporter/daemon"
)

var confInterval = time.Duration(0)

func InitFlags(fs *flag.FlagSet) {
	fs.DurationVar(&confInterval, "internal.interval", confInterval, "[internal] interval between polls")
}

var Factory = &internalDaemonFactory{}

type internalDaemonFactory struct{}

func (df *internalDaemonFactory) Daemons(inventory *common.Inventory) map[string]interface{} {
	return map[string]interface{}{
		"internal": struct{}{},
	}
}

func (df *internalDaemonFactory) New(params interface{}) daemon.DaemonI {
	return &internalDaemon{
		memAllocMax: 0,
	}
}

type internalDaemon struct {
	daemon.BaseDaemon

	memAllocMax uint64
}

func (d *internalDaemon) Interval() time.Duration {
	return confInterval
}

func (d *internalDaemon) Collect(ctx context.Context, m *common.MetricData) error {
	var mem runtime.MemStats
	runtime.ReadMemStats(&mem)
	if mem.Alloc > d.memAllocMax {
		d.memAllocMax = mem.Alloc
	}
	m.Set(&common.Metric{
		Name:   "self_mem_alloc_current",
		Labels: [][]string{},
		Value:  float64(mem.Alloc),
		TTL:    confInterval * 2,
	})
	m.Set(&common.Metric{
		Name:   "self_mem_alloc_max",
		Labels: [][]string{},
		Value:  float64(d.memAllocMax),
		TTL:    confInterval * 2,
	})
	m.Set(&common.Metric{
		Name:   "self_num_goroutines",
		Labels: [][]string{},
		Value:  float64(runtime.NumGoroutine()),
		TTL:    confInterval * 2,
	})

	return nil
}
