# `redis` module
It collects metrics from `redis` and `redissentinel` instances
## Metrics
Source: https://redis.io/commands/info
| Metric name | Labels | Description |
| ----------- | ------ | ---- |
| openio_redis_account_objects                  | `service`, `service_type`, `service_addr`, `account`    | Number of object per account |
| openio_redis_account_size_bytes               | `service`, `service_type`, `service_addr`, `account`    | Size per account |
| openio_redis_account_containers               | `service`, `service_type`, `service_addr`, `account`    | Number of container per account |
| openio_redis_db_keys                          | `service`, `service_type`, `service_addr`, `db`, `type` | `dbXXX: keys=XXX,expires=XXX`|
| openio_redis_is_standalone                    | `service`, `service_type`, `service_addr`               | Is redis standalone ? |
| openio_redis_is_master                    | `service`, `service_type`, `service_addr`               | Is redis master ? |
| openio_redis_is_sentinel                    | `service`, `service_type`, `service_addr`               | Is redis sentinel ? |
| openio_redis_uptime_seconds                   | `service`, `service_type`, `service_addr`               | uptime_in_seconds |
| openio_redis_clients                          | `service`, `service_type`, `service_addr`, `type`       | connected_clients, blocked_clients|
| openio_redis_memory_bytes                     | `service`, `service_type`, `service_addr`, `type`       | used_memory, used_memory_rss, used_memory_overhead, used_memory_dataset, used_memory_lua, used_memory_scripts |
| openio_redis_used_memory_bytes_max            | `service`, `service_type`, `service_addr`               | used_memory_peak |
| openio_redis_memory_fragmentation_ratio       | `service`, `service_type`, `service_addr`               | mem_fragmentation_ratio |
| openio_redis_active_defrag_is_running         | `service`, `service_type`, `service_addr`               | active_defrag_running |
| openio_redis_active_defrag                    | `service`, `service_type`, `service_addr`, `type`       | active_defrag_hits, active_defrag_misses, active_defrag_key_hits, active_defrag_key_misses |
| openio_redis_lazyfree_pending_objects         | `service`, `service_type`, `service_addr`               | lazyfree_pending_objects |
| openio_redis_rdb_changes_since_last_save      | `service`, `service_type`, `service_addr`               | rdb_changes_since_last_save |
| openio_redis_rdb_bgsave_in_progress           | `service`, `service_type`, `service_addr`               | rdb_bgsave_in_progress |
| openio_redis_rdb_last_save_time_seconds       | `service`, `service_type`, `service_addr`               | rdb_last_save_time |
| openio_redis_rdb_last_bgsave_status           | `service`, `service_type`, `service_addr`               | rdb_bgsave_in_progress|
| openio_redis_rdb_last_bgsave_time_seconds     | `service`, `service_type`, `service_addr`               | rdb_last_bgsave_time_sec |
| openio_redis_rdb_current_bgsave_time_seconds  | `service`, `service_type`, `service_addr`               | rdb_current_bgsave_time_sec |
| openio_redis_rdb_last_cow_size_bytes          | `service`, `service_type`, `service_addr`               | rdb_last_cow_size |
| openio_redis_aof_enabled                      | `service`, `service_type`, `service_addr`               | aof_enabled |
| openio_redis_aof_rewrite_in_progress          | `service`, `service_type`, `service_addr`               | aof_rewrite_in_progress |
| openio_redis_aof_rewrite_scheduled            | `service`, `service_type`, `service_addr`               | aof_rewrite_scheduled |
| openio_redis_aof_last_rewrite_time_seconds    | `service`, `service_type`, `service_addr`               | aof_last_rewrite_time_sec |
| openio_redis_aof_current_rewrite_time_seconds | `service`, `service_type`, `service_addr`               | aof_current_rewrite_time_sec |
| openio_redis_aof_last_bgrewrite_status        | `service`, `service_type`, `service_addr`               | aof_last_bgrewrite_status |
| openio_redis_aof_last_write_status            | `service`, `service_type`, `service_addr`               | aof_last_write_status |
| openio_redis_aof_last_cow_size_bytes          | `service`, `service_type`, `service_addr`               | aof_last_cow_size |
| openio_redis_aof_current_size_bytes           | `service`, `service_type`, `service_addr`               | aof_current_size |
| openio_redis_aof_base_size_bytes              | `service`, `service_type`, `service_addr`               | aof_base_size |
| openio_redis_aof_pending_rewrite              | `service`, `service_type`, `service_addr`               | aof_pending_rewrite |
| openio_redis_aof_buffer_length                | `service`, `service_type`, `service_addr`               | aof_buffer_length |
| openio_redis_aof_rewrite_buffer_length        | `service`, `service_type`, `service_addr`               | aof_rewrite_buffer_length |
| openio_redis_aof_pending_bio_fsync            | `service`, `service_type`, `service_addr`               | aof_pending_bio_fsync |
| openio_redis_aof_delayed_fsync_total          | `service`, `service_type`, `service_addr`               | aof_delayed_fsync |
| openio_redis_loading                          | `service`, `service_type`, `service_addr`               | loading |
| openio_redis_loading_start_time_seconds       | `service`, `service_type`, `service_addr`               | loading_start_time |
| openio_redis_loading_total_bytes              | `service`, `service_type`, `service_addr`               | loading_total_bytes |
| openio_redis_loading_loaded_bytes             | `service`, `service_type`, `service_addr`               | loading_loaded_bytes |
| openio_redis_loading_eta_seconds              | `service`, `service_type`, `service_addr`               | loading_start_time |
| openio_redis_rejected_connections_total       | `service`, `service_type`, `service_addr`               | rejected_connections|
| openio_redis_connections_total                | `service`, `service_type`, `service_addr`               | total_connections_received|
| openio_redis_commands_ops                     | `service`, `service_type`, `service_addr`               | instantaneous_ops_per_sec |
| openio_redis_commands_total                   | `service`, `service_type`, `service_addr`               | total_commands_processed |
| openio_redis_io_bytes_total                   | `service`, `service_type`, `service_addr`, `direction`  | total_net_input_bytes, total_net_output_bytes|
| openio_redis_io_kbps                          | `service`, `service_type`, `service_addr`, `direction`  | instantaneous_input_kbps, instantaneous_output_kbps |
| openio_redis_sync_full                        | `service`, `service_type`, `service_addr`               | sync_full |
| openio_redis_sync_partial                     | `service`, `service_type`, `service_addr`, `status`     | sync_partial_ok, sync_partial_err |
| openio_redis_keys_total                       | `service`, `service_type`, `service_addr`, `type`       | expired_keys, evicted_keys |
| openio_redis_keyspace_total                   | `service`, `service_type`, `service_addr`, `type`       | keyspace_hits, keyspace_misses |
| openio_redis_pubsub_channels                  | `service`, `service_type`, `service_addr`               | pubsub_channels |
| openio_redis_pubsub_patterns                  | `service`, `service_type`, `service_addr`               | pubsub_patterns |
| openio_redis_latest_fork_duration_seconds     | `service`, `service_type`, `service_addr`               | latest_fork_usec |
| openio_redis_migrate_cached_sockets           | `service`, `service_type`, `service_addr`               | migrate_cached_sockets |
| openio_redis_slave_expires_tracked_keys       | `service`, `service_type`, `service_addr`               | slave_expires_tracked_keys |
| openio_redis_role                             | `service`, `service_type`, `service_addr`, `role`       | role |
| openio_redis_repl_backlog_active              | `service`, `service_type`, `service_addr`               | repl_backlog_active |
| openio_redis_repl_backlog_size_bytes          | `service`, `service_type`, `service_addr`               | repl_backlog_size |
| openio_redis_master_link_status               | `service`, `service_type`, `service_addr`, `status`     | master_link_status |
| openio_redis_master_last_io_seconds           | `service`, `service_type`, `service_addr`               | master_last_io_seconds_ago |
| openio_redis_master_sync_in_progres           | `service`, `service_type`, `service_addr`               | master_sync_in_progress |
| openio_redis_slave_priority                   | `service`, `service_type`, `service_addr`               | slave_priority |
| openio_redis_slave_read_only                  | `service`, `service_type`, `service_addr`               | slave_read_only |
| openio_redis_master_sync_last_io_seconds      | `service`, `service_type`, `service_addr`               | master_sync_last_io_seconds_ago |
| openio_redis_master_link_down_since_seconds   | `service`, `service_type`, `service_addr`               | master_link_down_since_seconds |
| openio_redis_connected_slaves                 | `service`, `service_type`, `service_addr`               | connected_slaves |
| min_slaves_good_slaves                        | `service`, `service_type`, `service_addr`               | min_slaves_good_slaves |

### Sample
```
openio_redis_rdb_last_cow_size_bytes{host="gw.novalocal",namespace="OPENIO",service="OPENIO-redis-0",service_type="redis",service_addr="172.30.0.111:6011"} 2646016.000000
openio_redis_aof_last_bgrewrite_status{host="gw.novalocal",namespace="OPENIO",service="OPENIO-redis-0",service_type="redis",service_addr="172.30.0.111:6011"} 1.000000
openio_redis_commands_ops{host="gw.novalocal",namespace="OPENIO",service="OPENIO-redis-0",service_type="redis",service_addr="172.30.0.111:6011"} 6.000000
openio_redis_keys_total{host="gw.novalocal",namespace="OPENIO",service="OPENIO-redis-0",service_type="redis",service_addr="172.30.0.111:6011",type="expired"} 32.000000
openio_redis_memory_bytes{host="gw.novalocal",namespace="OPENIO",service="OPENIO-redis-0",service_type="redis",service_addr="172.30.0.111:6011",type="rss"} 13291520.000000
openio_redis_memory_fragmentation_ratio{host="gw.novalocal",namespace="OPENIO",service="OPENIO-redis-0",service_type="redis",service_addr="172.30.0.111:6011"} 1.930000
openio_redis_rdb_changes_since_last_save{host="gw.novalocal",namespace="OPENIO",service="OPENIO-redis-0",service_type="redis",service_addr="172.30.0.111:6011"} 356.000000
openio_redis_rdb_last_bgsave_status{host="gw.novalocal",namespace="OPENIO",service="OPENIO-redis-0",service_type="redis",service_addr="172.30.0.111:6011"} 1.000000
openio_redis_connected_slaves{host="gw.novalocal",namespace="OPENIO",service="OPENIO-redis-0",service_type="redis",service_addr="172.30.0.111:6011"} 2.000000
openio_redis_repl_backlog_active{host="gw.novalocal",namespace="OPENIO",service="OPENIO-redis-0",service_type="redis",service_addr="172.30.0.111:6011"} 1.000000
openio_redis_rdb_bgsave_in_progress{host="gw.novalocal",namespace="OPENIO",service="OPENIO-redis-0",service_type="redis",service_addr="172.30.0.111:6011"} 0.000000
openio_account_objects{host="gw.novalocal",namespace="OPENIO",service="OPENIO-redis-0",service_type="redis",service_addr="172.30.0.111:6011",account="MY_ACCOUNT"} 0.000000
openio_account_kiB{host="gw.novalocal",namespace="OPENIO",service="OPENIO-redis-0",service_type="redis",service_addr="172.30.0.111:6011",account="AUTH_96a9d76bae56499b995efe94e0f34773"} 2124853.857422
openio_redis_used_memory_bytes_max{host="gw.novalocal",namespace="OPENIO",service="OPENIO-redis-0",service_type="redis",service_addr="172.30.0.111:6011"} 14640664.000000
openio_redis_loading{host="gw.novalocal",namespace="OPENIO",service="OPENIO-redis-0",service_type="redis",service_addr="172.30.0.111:6011"} 0.000000
openio_redis_active_defrag{host="gw.novalocal",namespace="OPENIO",service="OPENIO-redis-0",service_type="redis",service_addr="172.30.0.111:6011",type="key_misses"} 0.000000
openio_redis_db_keys{host="gw.novalocal",namespace="OPENIO",service="OPENIO-redis-0",service_type="redis",service_addr="172.30.0.111:6011",db="0",type="expires"} 6.000000
openio_redis_lazyfree_pending_objects{host="gw.novalocal",namespace="OPENIO",service="OPENIO-redis-0",service_type="redis",service_addr="172.30.0.111:6011"} 0.000000
openio_redis_commands_total{host="gw.novalocal",namespace="OPENIO",service="OPENIO-redis-0",service_type="redis",service_addr="172.30.0.111:6011"} 23582942.000000
openio_redis_io_bytes_total{host="gw.novalocal",namespace="OPENIO",service="OPENIO-redis-0",service_type="redis",service_addr="172.30.0.111:6011",direction="in"} 993467356.000000
openio_redis_keys_total{host="gw.novalocal",namespace="OPENIO",service="OPENIO-redis-0",service_type="redis",service_addr="172.30.0.111:6011",type="evicted"} 0.000000
openio_redis_io_kbps{host="gw.novalocal",namespace="OPENIO",service="OPENIO-redis-0",service_type="redis",service_addr="172.30.0.111:6011",direction="in"} 0.380000
openio_redis_sync_full{host="gw.novalocal",namespace="OPENIO",service="OPENIO-redis-0",service_type="redis",service_addr="172.30.0.111:6011"} 2.000000
openio_redis_connections_total{host="gw.novalocal",namespace="OPENIO",service="OPENIO-redis-0",service_type="redis",service_addr="172.30.0.111:6011"} 2404771.000000
openio_redis_keyspace_total{host="gw.novalocal",namespace="OPENIO",service="OPENIO-redis-0",service_type="redis",service_addr="172.30.0.111:6011",type="misses"} 199327.000000
openio_redis_aof_rewrite_in_progress{host="gw.novalocal",namespace="OPENIO",service="OPENIO-redis-0",service_type="redis",service_addr="172.30.0.111:6011"} 0.000000
openio_redis_aof_current_rewrite_time_seconds{host="gw.novalocal",namespace="OPENIO",service="OPENIO-redis-0",service_type="redis",service_addr="172.30.0.111:6011"} -1.000000
openio_redis_aof_last_write_status{host="gw.novalocal",namespace="OPENIO",service="OPENIO-redis-0",service_type="redis",service_addr="172.30.0.111:6011"} 1.000000
openio_redis_aof_last_cow_size_bytes{host="gw.novalocal",namespace="OPENIO",service="OPENIO-redis-0",service_type="redis",service_addr="172.30.0.111:6011"} 2813952.000000
openio_account_objects{host="gw.novalocal",namespace="OPENIO",service="OPENIO-redis-0",service_type="redis",service_addr="172.30.0.111:6011",account="AUTH_96a9d76bae56499b995efe94e0f34773"} 53278.000000
openio_redis_memory_bytes{host="gw.novalocal",namespace="OPENIO",service="OPENIO-redis-0",service_type="redis",service_addr="172.30.0.111:6011",type="overhead"} 2376540.000000
openio_redis_active_defrag_is_running{host="gw.novalocal",namespace="OPENIO",service="OPENIO-redis-0",service_type="redis",service_addr="172.30.0.111:6011"} 0.000000
openio_redis_rdb_last_save_time_seconds{host="gw.novalocal",namespace="OPENIO",service="OPENIO-redis-0",service_type="redis",service_addr="172.30.0.111:6011"} 1588084344.000000
openio_redis_aof_buffer_length{host="gw.novalocal",namespace="OPENIO",service="OPENIO-redis-0",service_type="redis",service_addr="172.30.0.111:6011"} 0.000000
openio_redis_aof_rewrite_buffer_length{host="gw.novalocal",namespace="OPENIO",service="OPENIO-redis-0",service_type="redis",service_addr="172.30.0.111:6011"} 0.000000
openio_redis_aof_delayed_fsync_total{host="gw.novalocal",namespace="OPENIO",service="OPENIO-redis-0",service_type="redis",service_addr="172.30.0.111:6011"} 0.000000
openio_redis_slave_expires_tracked_keys{host="gw.novalocal",namespace="OPENIO",service="OPENIO-redis-0",service_type="redis",service_addr="172.30.0.111:6011"} 0.000000
openio_redis_pubsub_patterns{host="gw.novalocal",namespace="OPENIO",service="OPENIO-redis-0",service_type="redis",service_addr="172.30.0.111:6011"} 0.000000
openio_redis_active_defrag{host="gw.novalocal",namespace="OPENIO",service="OPENIO-redis-0",service_type="redis",service_addr="172.30.0.111:6011",type="key_hits"} 0.000000
openio_redis_pubsub_channels{host="gw.novalocal",namespace="OPENIO",service="OPENIO-redis-0",service_type="redis",service_addr="172.30.0.111:6011"} 1.000000
openio_redis_active_defrag{host="gw.novalocal",namespace="OPENIO",service="OPENIO-redis-0",service_type="redis",service_addr="172.30.0.111:6011",type="hits"} 0.000000
openio_redis_is_standalone{host="gw.novalocal",namespace="OPENIO",service="OPENIO-redis-0",service_type="redis",service_addr="172.30.0.111:6011"} 1.000000
openio_redis_rdb_current_bgsave_time_sec{host="gw.novalocal",namespace="OPENIO",service="OPENIO-redis-0",service_type="redis",service_addr="172.30.0.111:6011"} -1.000000
openio_redis_aof_base_size_bytes{host="gw.novalocal",namespace="OPENIO",service="OPENIO-redis-0",service_type="redis",service_addr="172.30.0.111:6011"} 1988173.000000
openio_redis_sync_partial{host="gw.novalocal",namespace="OPENIO",service="OPENIO-redis-0",service_type="redis",service_addr="172.30.0.111:6011",status="err"} 0.000000
openio_redis_memory_bytes{host="gw.novalocal",namespace="OPENIO",service="OPENIO-redis-0",service_type="redis",service_addr="172.30.0.111:6011",type="lua"} 69632.000000
openio_redis_sync_partial{host="gw.novalocal",namespace="OPENIO",service="OPENIO-redis-0",service_type="redis",service_addr="172.30.0.111:6011",status="ok"} 0.000000
openio_redis_role{host="gw.novalocal",namespace="OPENIO",service="OPENIO-redis-0",service_type="redis",service_addr="172.30.0.111:6011",role="master"} 1.000000
openio_account_kiB{host="gw.novalocal",namespace="OPENIO",service="OPENIO-redis-0",service_type="redis",service_addr="172.30.0.111:6011",account="MY_ACCOUNT"} 0.000000
openio_redis_migrate_cached_sockets{host="gw.novalocal",namespace="OPENIO",service="OPENIO-redis-0",service_type="redis",service_addr="172.30.0.111:6011"} 0.000000
openio_redis_memory_bytes{host="gw.novalocal",namespace="OPENIO",service="OPENIO-redis-0",service_type="redis",service_addr="172.30.0.111:6011",type="total"} 6886288.000000
openio_redis_io_kbps{host="gw.novalocal",namespace="OPENIO",service="OPENIO-redis-0",service_type="redis",service_addr="172.30.0.111:6011",direction="out"} 1.360000
openio_redis_active_defrag{host="gw.novalocal",namespace="OPENIO",service="OPENIO-redis-0",service_type="redis",service_addr="172.30.0.111:6011",type="misses"} 0.000000
openio_redis_aof_pending_bio_fsync{host="gw.novalocal",namespace="OPENIO",service="OPENIO-redis-0",service_type="redis",service_addr="172.30.0.111:6011"} 0.000000
openio_redis_memory_bytes{host="gw.novalocal",namespace="OPENIO",service="OPENIO-redis-0",service_type="redis",service_addr="172.30.0.111:6011",type="dataset"} 4509748.000000
openio_redis_rdb_last_bgsave_time_seconds{host="gw.novalocal",namespace="OPENIO",service="OPENIO-redis-0",service_type="redis",service_addr="172.30.0.111:6011"} 0.000000
openio_redis_aof_current_size_bytes{host="gw.novalocal",namespace="OPENIO",service="OPENIO-redis-0",service_type="redis",service_addr="172.30.0.111:6011"} 9963203.000000
openio_redis_keyspace_total{host="gw.novalocal",namespace="OPENIO",service="OPENIO-redis-0",service_type="redis",service_addr="172.30.0.111:6011",type="hits"} 10415884.000000
openio_redis_uptime_seconds{host="gw.novalocal",namespace="OPENIO",service="OPENIO-redis-0",service_type="redis",service_addr="172.30.0.111:6011"} 712086.000000
openio_redis_aof_last_rewrite_time_seconds{host="gw.novalocal",namespace="OPENIO",service="OPENIO-redis-0",service_type="redis",service_addr="172.30.0.111:6011"} 0.000000
openio_redis_aof_pending_rewrite{host="gw.novalocal",namespace="OPENIO",service="OPENIO-redis-0",service_type="redis",service_addr="172.30.0.111:6011"} 0.000000
openio_redis_io_bytes_total{host="gw.novalocal",namespace="OPENIO",service="OPENIO-redis-0",service_type="redis",service_addr="172.30.0.111:6011",direction="out"} 3116267930.000000
openio_redis_account_containers{host="gw.novalocal",namespace="OPENIO",service="OPENIO-redis-0",service_type="redis",service_addr="172.30.0.111:6011",account="AUTH_96a9d76bae56499b995efe94e0f34773"} 4454.000000
openio_redis_latest_fork_duration_seconds{host="gw.novalocal",namespace="OPENIO",service="OPENIO-redis-0",service_type="redis",service_addr="172.30.0.111:6011"} 0.001211
openio_redis_account_containers{host="gw.novalocal",namespace="OPENIO",service="OPENIO-redis-0",service_type="redis",service_addr="172.30.0.111:6011",account="MY_ACCOUNT"} 0.000000
openio_redis_repl_backlog_size_bytes{host="gw.novalocal",namespace="OPENIO",service="OPENIO-redis-0",service_type="redis",service_addr="172.30.0.111:6011"} 1048576.000000
openio_redis_db_keys{host="gw.novalocal",namespace="OPENIO",service="OPENIO-redis-0",service_type="redis",service_addr="172.30.0.111:6011",db="0",type="keys"} 4474.000000
openio_redis_clients{host="gw.novalocal",namespace="OPENIO",service="OPENIO-redis-0",service_type="redis",service_addr="172.30.0.111:6011",type="connected"} 0.000000
openio_redis_aof_enabled{host="gw.novalocal",namespace="OPENIO",service="OPENIO-redis-0",service_type="redis",service_addr="172.30.0.111:6011"} 1.000000
openio_redis_aof_rewrite_scheduled{host="gw.novalocal",namespace="OPENIO",service="OPENIO-redis-0",service_type="redis",service_addr="172.30.0.111:6011"} 0.000000
openio_redis_rejected_connections_total{host="gw.novalocal",namespace="OPENIO",service="OPENIO-redis-0",service_type="redis",service_addr="172.30.0.111:6011"} 0.000000
```
