package static

import (
	"context"
	"testing"

	"github.com/open-io/oio-exporter/common"
	"github.com/open-io/oio-exporter/testutils"
)

func TestStaticModule(t *testing.T) {
	t.Parallel()

	m := common.MakeMetricData()
	params := &staticDaemonParams{
		Namespace: "TESTNAMESPACE",
		Localname: "test-host",
		Rack:      "test.rack",
	}
	d := Factory.New(params)
	ctx := context.TODO()

	if err := d.Init(ctx); err != nil {
		t.Fatalf("Init error: %s", err)
	}

	if err := d.Collect(ctx, m); err != nil {
		t.Fatalf("Collect error: %s", err)
	}

	if err := d.Close(); err != nil {
		t.Fatalf("Close error: %s", err)
	}

	testutils.NewMetricDataTest().
		ForMetric(
			testutils.NewMetricAssertion().
				LabelIs("namespace", "TESTNAMESPACE").
				LabelIs("localname", "test-host").
				LabelIs("rack", "test.rack").
				NoExtraLabels(),
			"static_host").
		NoExtraMetrics().
		Check(t, m)
}
